<?php
/*
 *  Plugin Name: Vasaio QR Code
 *  Plugin URI: http://qr-gen.tk/
 *  Description: Generate standalone QR codes, colored and customized with logo inside.
 *  Author: Marius OLAR
 *  Version: 1.1
 *  Author URI: http://olarmarius.tk/
 *  License: GPLv3
 *
 */

define(VQRC_TEXTDOMAIN, 'vasaio-qr-code');

//----------------------------------------------------------------------------------------
function vasaio_qr_code_init() {
  load_plugin_textdomain( VQRC_TEXTDOMAIN, false, 'vasaio-qr-code/languages' );
}
add_action('plugins_loaded', 'vasaio_qr_code_init');

//----------------------------------------------------------------------------------------
function vasaio_qr_code_activate() {
  add_option('vasaio_qr_side', '256', 'dimensiunea imaginii in pixeli (64, ... 256=default, ... 3000)');
  add_option('vasaio_qr_correction', 'L', 'nivelul de corectie al erorilor (L=7%(default), M=15%, Q=25%, H=30%)');
  add_option('vasaio_qr_filetype', 'PNG', '(PNG=default, JPEG, GIF)');
  add_option('vasaio_qr_border', '4', '(2, 3, 4=default, ... 10)');
  add_option('vasaio_qr_color', '40013c', '(default=black)');
  add_option('vasaio_qr_logo', site_url().'/wp-content/plugins/vasaio-qr-code/images/VASAIO-QR-Code-logo2.png', '(default=none)');
  add_option('vasaio_qr_percent', '7', '(default=7)');
  add_option('vasaio_qr_adjust', '1', '(default=1)');
  
  $all_options = '?';
  $all_options .= 's='.get_option('vasaio_qr_side');
  $all_options .= '&x='.get_option('vasaio_qr_correction');
  $all_options .= '&t='.get_option('vasaio_qr_filetype');
  $all_options .= '&b='.get_option('vasaio_qr_border');
  $all_options .= '&c='.get_option('vasaio_qr_color');
  $all_options .= '&o='.get_option('vasaio_qr_logo');
  $all_options .= '&p='.get_option('vasaio_qr_percent');
  $all_options .= '&a='.get_option('vasaio_qr_adjust');
  add_option('vasaio_qr_all_options', $all_options, '?');
}

//----------------------------------------------------------------------------------------
function vasaio_qr_code_deactivate() {
  delete_option('vasaio_qr_side');
  delete_option('vasaio_qr_correction');
  delete_option('vasaio_qr_filetype');
  delete_option('vasaio_qr_border');
  delete_option('vasaio_qr_color');
  delete_option('vasaio_qr_logo');
  delete_option('vasaio_qr_percent');
  delete_option('vasaio_qr_adjust');
  delete_option('vasaio_qr_all_options');
}

register_activation_hook( __FILE__, 'vasaio_qr_code_activate' );
register_deactivation_hook( __FILE__, 'vasaio_qr_code_deactivate' );


//----------------------------------------------------------------------------------------------
//  USE OF Vasaio QR CODE ENCODER
//----------------------------------------------------------------------------------------------
//
//  USE:  	vasaio-qr-code-encoder.php?m=message&s=side&x=correction&t=filetype&b=border&d=download
//
//  WHERE:
//
//		m=message		->	data to encode (default=http://vasaio.tk)
//		s=side			->	dimension of image in pixels (64, ... 256=default, ... 3000)
//		x=correction	->	error correction level (L=7%(default), M=15%, Q=25%, H=30%) - case insensitive
//		t=filetype		->	file type of image (PNG=default, JPEG, GIF) - case insensitive
//		b=border		->	number of squares for qr code white border (2, 3, 4=default, ... 10)
//		d=download		->	if you just want to download the file, set this param to 1 (1 / 0=default)
//		c=color			->	hex code of the main color (default=black)
//		o=logo			->	filename of logo image, if you want to appear into the QR code (default=null)
//		p=percent		->	percent of logo image, if you want to appear into the QR code (default=7)
//		a=adjust		->	automatic adjust the logo width & height to match with squares (default=1)
//
//	EX:		vasaio-qr-code-encoder/vasaio-qr-code-encoder.php?m=http://vasaio.tk&s=400&x=M&t=gif&b=2
//
//----------------------------------------------------------------------------------------------

//----------------------------------------------------------------------------------------------

function admin_vasaio_qr_options() {
  ?><div class="wrap"><h2>Vasaio QR Code - <?php echo __('Settings', VQRC_TEXTDOMAIN); ?></h2><?php

  if ($_REQUEST['submit']) {
     update_vasaio_qr_options();
  }
  print_vasaio_qr_form();

  ?></div><?php
}

//----------------------------------------------------------------------------------------------

function update_vasaio_qr_options() {
  $all_options = '?';
  $eroare = '';
  $ok = false; if ($_REQUEST['vasaio_qr_side']) { update_option('vasaio_qr_side', $_REQUEST['vasaio_qr_side']);  $ok = true; $all_options .= 's='.$_REQUEST['vasaio_qr_side'];} else {$eroare.='2';}
  $ok = false; if ($_REQUEST['vasaio_qr_correction']) { update_option('vasaio_qr_correction', $_REQUEST['vasaio_qr_correction']);  $ok = true; $all_options .= '&x='.$_REQUEST['vasaio_qr_correction'];} else {$eroare.='3';}
  $ok = false; if ($_REQUEST['vasaio_qr_filetype']) { update_option('vasaio_qr_filetype', $_REQUEST['vasaio_qr_filetype']);  $ok = true; $all_options .= '&t='.$_REQUEST['vasaio_qr_filetype'];} else {$eroare.='4';}
  $ok = false; if ($_REQUEST['vasaio_qr_border']) { update_option('vasaio_qr_border', $_REQUEST['vasaio_qr_border']);  $ok = true; $all_options .= '&b='.$_REQUEST['vasaio_qr_border'];} else {$eroare.='5';}
  $ok = false; if ($_REQUEST['vasaio_qr_color']) { update_option('vasaio_qr_color', $_REQUEST['vasaio_qr_color']);  $ok = true; $all_options .= '&c='.$_REQUEST['vasaio_qr_color'];} else {$eroare.='6';}
  $ok = false; if (isset($_REQUEST['vasaio_qr_logo'])) { update_option('vasaio_qr_logo', $_REQUEST['vasaio_qr_logo']);  $ok = true; if($_REQUEST['vasaio_qr_logo']) $all_options .= '&o='.$_REQUEST['vasaio_qr_logo'];} else {$eroare.='7';}
  $ok = false; if (isset($_REQUEST['vasaio_qr_percent'])) { update_option('vasaio_qr_percent', $_REQUEST['vasaio_qr_percent']);  $ok = true; $all_options .= '&p='.$_REQUEST['vasaio_qr_percent'];} else {$eroare.='8';}
  $ok = false; if (isset($_REQUEST['vasaio_qr_adjust'])) { update_option('vasaio_qr_adjust', $_REQUEST['vasaio_qr_adjust']);  $ok = true; $all_options .= '&a='.$_REQUEST['vasaio_qr_adjust'];} else {$eroare.='9';}
  $ok = false; if ($all_options) { update_option('vasaio_qr_all_options', $all_options);  $ok = true; } else {$eroare.='0';}
 
  if ($ok) {
    ?><div id="message" class="updated fadee">
       <p>Mesaj Vasaio QR Code: <strong> Optiuni salvate!</strong></p>
      </div><?php
  } else {
       ?><div id="message" class="error fade">
         <p>Mesaj Vasaio QR Code: <strong> Eroare la salvarea optiunilor! (<?php echo $eroare;?>) </strong></p>
         </div><?php
  }
}

//----------------------------------------------------------------------------------------------

function print_vasaio_qr_form() {
  $default_vasaio_qr_side = get_option('vasaio_qr_side');
  $default_vasaio_qr_correction = get_option('vasaio_qr_correction');
  $default_vasaio_qr_filetype = get_option('vasaio_qr_filetype');
  $default_vasaio_qr_border = get_option('vasaio_qr_border');
  $default_vasaio_qr_color = get_option('vasaio_qr_color');
  $default_vasaio_qr_logo = get_option('vasaio_qr_logo');
  $default_vasaio_qr_percent = get_option('vasaio_qr_percent');
  $default_vasaio_qr_adjust = get_option('vasaio_qr_adjust');
  $default_vasaio_qr_options = get_option('vasaio_qr_all_options');

  ?>

<?php echo '<div style="float:left; width:100%; height:auto;" ><div style="float:left; width:auto; height:auto; border:solid 1px; margin:10px;"><img src="'.get_bloginfo('siteurl').'/wp-content/plugins/vasaio-qr-code/vasaio-qr-code-encoder/vasaio-qr-code-encoder.php'.$default_vasaio_qr_options.'&m=http://vasaio.tk" /></div></div>';?>

  <div style="float:left; width:auto; height:auto; padding:10px;margin:10px;" class="postbox">
  <form method="POST">
  <table>
  <tbody>
  
  <tr>
	<td colspan="3"><?php echo __('To use this plugin just put the [vasaioqrcode] shortcode into the content of the page. For more examples visit: ', VQRC_TEXTDOMAIN); ?><a href="http://wordpress.org/extend/plugins/vasaio-qr-code/screenshots/" target="_blank">http://wordpress.org/extend/plugins/vasaio-qr-code/screenshots/</a></td>
  </tr>

  <tr>
    <td><label for="vasaio_qr_side"><?php echo __('Wide of image', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><input type="text" name="vasaio_qr_side" value="<?php echo$default_vasaio_qr_side;?>" /></td>
    <td><?php echo __('image size in pixels (64, ... 256 = default, ... 3000)', VQRC_TEXTDOMAIN); ?></td>
  </tr>

  <tr style="background-color:aliceblue;">
    <td><label for="vasaio_qr_correction"><?php echo __('Correction of destruction', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><select name="vasaio_qr_correction">
        <option value="L" <?php if($default_vasaio_qr_correction=='L')echo' selected=selected ';?> /><?php echo __('Low (L=7%)', VQRC_TEXTDOMAIN); ?></option>
        <option value="M" <?php if($default_vasaio_qr_correction=='M')echo' selected=selected ';?> /><?php echo __('Medium (M=15%)', VQRC_TEXTDOMAIN); ?></option>
        <option value="Q" <?php if($default_vasaio_qr_correction=='Q')echo' selected=selected ';?> /><?php echo __('Quality (Q=25%)', VQRC_TEXTDOMAIN); ?></option>
        <option value="H" <?php if($default_vasaio_qr_correction=='H')echo' selected=selected ';?> /><?php echo __('High (H=30%)', VQRC_TEXTDOMAIN); ?></option>
	  </select></td>
    <td><?php echo __('the correction of errors (L = 7% (default), M = 15%, Q = 25%, H = 30%)', VQRC_TEXTDOMAIN); ?></td>
  </tr>

  <tr>
    <td><label for="vasaio_qr_filetype"><?php echo __('Image filetype', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><select name="vasaio_qr_filetype">
        <option value="PNG" <?php if($default_vasaio_qr_filetype=='PNG')echo' selected=selected ';?> />PNG</option>
        <option value="JPEG" <?php if($default_vasaio_qr_filetype=='JPEG')echo' selected=selected ';?> />JPEG</option>
        <option value="GIF" <?php if($default_vasaio_qr_filetype=='GIF')echo' selected=selected ';?> />GIF</option>
	  </select></td>
    <td>(PNG=default, JPEG, GIF)</td>
  </tr>

  <tr style="background-color:aliceblue;">
    <td><label for="vasaio_qr_border"><?php echo __('Edge size', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><select name="vasaio_qr_border">
        <option value="2" <?php if($default_vasaio_qr_border=='2')echo' selected=selected ';?> />2</option>
        <option value="3" <?php if($default_vasaio_qr_border=='3')echo' selected=selected ';?> />3</option>
        <option value="4" <?php if($default_vasaio_qr_border=='4')echo' selected=selected ';?> />4</option>
        <option value="5" <?php if($default_vasaio_qr_border=='5')echo' selected=selected ';?> />5</option>
        <option value="6" <?php if($default_vasaio_qr_border=='6')echo' selected=selected ';?> />6</option>
        <option value="7" <?php if($default_vasaio_qr_border=='7')echo' selected=selected ';?> />7</option>
        <option value="8" <?php if($default_vasaio_qr_border=='8')echo' selected=selected ';?> />8</option>
        <option value="9" <?php if($default_vasaio_qr_border=='9')echo' selected=selected ';?> />9</option>
        <option value="10" <?php if($default_vasaio_qr_border=='10')echo' selected=selected ';?> />10</option>
	  </select></td>
    <td><?php echo __('number of squares of the edge (2, 3, 4 = default, ... 10)', VQRC_TEXTDOMAIN); ?></td>
  </tr>

  <script type="text/javascript" src="<?php echo get_bloginfo('siteurl');?>/wp-content/plugins/vasaio-qr-code/vasaio-qr-code-encoder/jscolor/jscolor.js"></script>
  <tr>
    <td><label for="vasaio_qr_color"><?php echo __('Main color', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><input type="text" name="vasaio_qr_color" value="<?php echo$default_vasaio_qr_color;?>" class="color" /></td>
    <td><?php echo __('squares color (default = black)', VQRC_TEXTDOMAIN); ?></td>
  </tr>

  <tr style="background-color:aliceblue;">
    <td><label for="vasaio_qr_logo"><?php echo __('Logo', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><input type="text" name="vasaio_qr_logo" value="<?php echo$default_vasaio_qr_logo;?>" /></td>
    <td><?php echo __('this logo will appear in all qr codes', VQRC_TEXTDOMAIN); ?></td>
  </tr>

  <tr>
    <td><label for="vasaio_qr_percent"><?php echo __('Logo area', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><input type="text" name="vasaio_qr_percent" value="<?php echo$default_vasaio_qr_percent;?>" /></td>
    <td><?php echo __('logo coverage (percentage of QR code - recommendation 10%)', VQRC_TEXTDOMAIN); ?></td>
  </tr>

  <tr style="background-color:aliceblue;">
    <td><label for="vasaio_qr_adjust"><?php echo __('Automatic adjustment', VQRC_TEXTDOMAIN); ?>:</label></td>
    <td><select name="vasaio_qr_adjust">
        <option value="1" <?php if($default_vasaio_qr_adjust=='1')echo' selected=selected ';?> /><?php echo __('automatic', VQRC_TEXTDOMAIN); ?></option>
        <option value="0" <?php if($default_vasaio_qr_adjust=='0')echo' selected=selected ';?> /><?php echo __('without adjustment', VQRC_TEXTDOMAIN); ?></option>
	  </select></td>
    <td><?php echo __('automatic adjustment of the logo', VQRC_TEXTDOMAIN); ?></td>
  </tr> 
  
  <tr>
    <td colspan="3"><hr></td>
  </tr>

  <tr>
    <td colspan="3"><input type="submit" name="submit" value="<?php echo __('Save', VQRC_TEXTDOMAIN); ?>" /></td>
  </tr>
  </tbody>
  </table>
  </form>
  </div>
  <?php
}

//----------------------------------------------------------------------------------------------

function vasaio_qr_code_style()
{
	echo'
	<style type="text/css">
	.vasaio-qr-code { margin:10px;}
	</style>
	';
}

add_action('wp_head', 'vasaio_qr_code_style');

//----------------------------------------------------------------------------------------------

function vasaio_qr_code_menu() {
  add_options_page(
    'Vasaio QR Code - '.__('Settings', VQRC_TEXTDOMAIN), // page title
    'Vasaio QR Code', // submenu title
    'manage_options', // access/capability
    __FILE__, // file
    'admin_vasaio_qr_options' // function
  );
}

add_action('admin_menu', 'vasaio_qr_code_menu');

//----------------------------------------------------------------------------------------------

function vasaio_qr_code_shortcode( $atts )
{
//echo '<div style="float:left; width:100%; height:auto;" ><div style="float:left; width:auto; height:auto; border:solid 0px; margin:0;"><img src="'.get_bloginfo('siteurl').'/wp-content/plugins/vasaio-qr-code/vasaio-qr-code-encoder/vasaio-qr-code-encoder.php'.get_option('vasaio_qr_all_options').'&m=http://vasaio.tk" /></div></div>';
//echo '<div style="float:left; width:auto; height:auto; border:solid 0px; margin:10px;"><img src="'.get_bloginfo('siteurl').'/wp-content/plugins/vasaio-qr-code/vasaio-qr-code-encoder/vasaio-qr-code-encoder.php'.get_option('vasaio_qr_all_options').'&m=http://vasaio.tk" /></div>';

extract( shortcode_atts( array(
		's' => get_option('vasaio_qr_side'),
		'x' => get_option('vasaio_qr_correction'),
		't' => get_option('vasaio_qr_filetype'),
		'b' => get_option('vasaio_qr_border'),
		'c' => get_option('vasaio_qr_color'),
		'o' => get_option('vasaio_qr_logo'),
		'p' => get_option('vasaio_qr_percent'),
		'a' => get_option('vasaio_qr_adjust'),
		'm' => get_permalink()
	), $atts ) );

  $all_options = "?";
  $all_options .= "s={$s}";
  $all_options .= "&x={$x}";
  $all_options .= "&t={$t}";
  $all_options .= "&b={$b}";
  $all_options .= "&c={$c}";
  $all_options .= "&o={$o}";
  $all_options .= "&p={$p}";
  $all_options .= "&a={$a}";
  $all_options .= "&m={$m}";

return '<img src="'.get_bloginfo('siteurl').'/wp-content/plugins/vasaio-qr-code/vasaio-qr-code-encoder/vasaio-qr-code-encoder.php'.$all_options.'" class="vasaio-qr-code"/>';
}

add_shortcode('vasaioqrcode', 'vasaio_qr_code_shortcode');

?>